@@ -6,8 +6,9 @@ var path = require('path')
 var write = require('./lib/write')
 
 var URL = 'https://svn.apache.org/repos/asf/httpd/httpd/trunk/modules/http/http_protocol.c'
+var HEADERS = { 'User-Agent': 'nodejs/' + process.version + ' (' + process.platform + ', npm:statuses)' }
 
-https.get(URL, function onResponse (res) {
+https.get(URL, { headers: HEADERS }, function onResponse (res) {
   getBody(res, true, function (err, body) {
     if (err) throw err
 
